/*

   This code will blink an LED attached to pin 13 on and off. 
   It will stay on for 0.25 seconds. It will stay off for 1 second.
   
   See also sample project Dutycycle
   
 */
#include <Metro.h> //Include Metro library
#define LED 13 // Define the led's pin

//Create a variable to hold theled's current state
int state = LOW;

uint32_t onTime = 750;
uint32_t offTime = 250;
uint32_t stopTime = 10000;

uint32_t prevTime;
uint32_t currentDelay;

Metro ledTimer;
Metro stopTimer;   

//==============================================================
void setup() {
  
  Serial.begin(9600);
  delay(500);
  Serial.println("[blinking_2_intervals]");
  Serial.print("Metro library version: "); Serial.println(Metro_VERSION);
  Serial.println("Demonstrates the use of the Metro library.\n");
  Serial.println("Blinking pin 13 at two intervals using one timer.");
  Serial.print("Blinking stops after: "); Serial.print(stopTime);  Serial.println(" ms .");
  Serial.println();
  
  state = LOW;
  pinMode(LED, OUTPUT);
  digitalWrite(LED, state);
  
  currentDelay = offTime;
  Serial.println("Starting the timers ...");
  
  prevTime = millis();                        // start measuring timer
  ledTimer = Metro(currentDelay);             // set the interval and start the timer
  
  stopTimer = Metro(stopTime);                   // stops after 10 seconds
  Serial.print("Stoptimer is set to: "); Serial.print(stopTime); Serial.println(" ms.\n");
  
  Serial.print("Timer is set to: "); Serial.print(currentDelay); Serial.print(" ms ...");
}

//==============================================================
void loop()
{

  if (ledTimer.check()) { // check if the metro has passed its interval .
  
    Serial.print("   \tInterval was: "); Serial.print(millis() - prevTime); Serial.print(" ms\n");
  
    if (state == HIGH)  { 
      
      currentDelay = offTime;   // if the pin is HIGH, set pin LOW and set the interval to offTime ms.
      state = LOW;
      
    } else {
  
      currentDelay = onTime;  // if the pin is LOW, set pin HIGH and set the interval to onTime ms.
      state = HIGH;
    }
    
    prevTime = millis();                         // restart measuring timer
    ledTimer.interval(currentDelay);
    digitalWrite(LED, state);
    Serial.print("Timer is set to: "); Serial.print(currentDelay); Serial.print(" ms ...");
    
  }
  
  // To demonstrate we can stop the timers
  if (stopTimer.check()) { 
    
      ledTimer.disable();          // disable the timers 
      stopTimer.disable(); 
      
      digitalWrite(LED, LOW);     // turn the LED off
      Serial.println("\n\nBlinking has stopped.");      
  }
  
  
  //
  // do some other tasks here ...
  //
  
}

