/*
 Dutycycle
 
 This code will blink an LED attached to pin 13 on and off with a defined dutycycle (0-100).
 A fixed cycletime length is 1 second.
 
 For a dutycycle of 25 it will stay on for 0.25 seconds and off for 0.75 seconds. Totals 1 second cycletime.
 For a dutycycle of 80 the on time is 0.8 seconds and off for 0.2 seconds.
 
 */
 
#include <Metro.h>     // Include Metro library
#define LEDpin 13      // Define the led's pin

uint32_t cycleTime = 2000;   // milliseconds
uint8_t dutycycle;

uint32_t onTime ;
uint32_t offTime ;

// Instantiate a metro object and set the interval to 1000 * dutycycle / 100 seconds (250 milliseconds).
Metro ledTimer; 

//----------------------------------------------------------------------
void setDutycycle(uint8_t newDC) {
   dutycycle = newDC;
   onTime = cycleTime * dutycycle / 100;
   offTime = cycleTime - cycleTime * dutycycle / 100;
   Serial.print("Dutycycle = "); Serial.print(dutycycle); Serial.println("%");
}

//=================================================================================
void setup()
{
  Serial.begin(9600);
  delay(500);
  Serial.println("[Dutycycle]");
  Serial.print("Metro library version: "); Serial.println(Metro_VERSION);
  Serial.println("Demonstrates the use of the Metro library.");
  Serial.println("Using one timer with alternating timings.\n");
  
  Serial.println("Enter a '+' or a '-' to increase or decrease the dutycycle.\n");
  
  Serial.print("Cycle time = "); Serial.println(cycleTime);
  
  setDutycycle(75);   // start with a 50% dutycycle; onTime and offTime are (re-)calculated.
  
  Serial.print("On time = "); Serial.println(onTime);
  Serial.print("Off time = "); Serial.println(offTime);
  Serial.println();
  
  pinMode(LEDpin, OUTPUT);
  digitalWrite(LEDpin, LOW);
  
  ledTimer = Metro(offTime);                    // instantiate the Metro object and starts the timer.
  Serial.println("The LED timer is started.");
}

//=================================================================================
void loop()
{

  // Check the timer
  //
  if (ledTimer.check()) {                   // check if the metro has passed its interval .
    if (digitalRead(LEDpin) == HIGH)  {
      digitalWrite(LEDpin,LOW);
      ledTimer.interval(offTime);      // restart the timer with a new interval offTime
    }else{ 
      digitalWrite(LEDpin,HIGH);
      ledTimer.interval(onTime);      // restart the timer with a new interval onTime
    }
  }
  
  // Check for user input
  //
  if (Serial.available()) {              // process keyboard input:  '+' or '-' to increase or decrrease the dutycycle
    char c = Serial.read();
    
    uint8_t newdc;
    switch (c) {
      
      case '+':
        newdc = dutycycle + 5;
        if (newdc > 100) newdc = 100;
        setDutycycle(newdc);
        break;
        
      case '-':
        newdc = dutycycle - 5;
        if (newdc < 0) newdc = 0;
        setDutycycle(newdc);
        break;
        
    } // switch c
    
  } // if Serial.available()
  
} // loop()



